
export interface IPaymentOptions{
    /**
     * Merchant's code, can be found on your dashboard
     */
    merchantCode: string;

    /**
     * The Pay item ID can be found on your dashboard
     */
    payItemID: string;

    /**
     * The name of the item the customer is paying for
     */
    payItemName?: string;

    /**
     * The transaction reference is automatically generated by the library.
     * You can decide to create yours
     */
    transactionReference: string;

    /**
     * Amount of the item being paid for (in kobo)
     */
    amount: string;

    /**
     * ISO 4217 code of the currency being used. Naira(566) is the default
     */
    currency: number;

    /**
     * The site to be redirected to after a successful transaction
     */
    siteRedirectURL?: string;

    /**
     * Transaction Mode ('LIVE' or 'TEST'). 'TEST' is the default
     */
    paymentMode: string;

    /**
     * Name of the customer
     */
    customerName?: string;

    /**
     * Email of the customer
     */
    customerEmail: string;

    /**
     * ID of the customer
     */
    customerID?: string;

    /**
     * Flag to indicate whether you want the customer's card to be tokenised, 
     * a tokenised value would be returned when you requery to confrim the transaction status
     */
    tokeniseCard?: boolean;

    /**
     * Access token value gotten from passport
     */
    accessToken?: boolean;


}