
export interface IPaymentRequest{
    /**
     * Merchant's code, can be found on your dashboard
     */
    merchant_code: string;

    /**
     * The Pay item ID can be found on your dashboard
     */
    pay_item_id: string;

    /**
     * The name of the item the customer is paying for
     */
    pay_item_name: string;

    /**
     * The transaction reference is automatically generated by the library.
     * You can decide to create yours
     */
    txn_ref: string;

    /**
     * Amount of the item being paid for (in koboa)
     */
    amount: string;

    /**
     * ISO 4217 code of the currency being used. Naira(566) is the default
     */
    currency: number;

    /**
     * The site to be redirected to after a successful transaction
     */
    site_redirect_url: string;

    /**
     * Transaction Mode ('LIVE' or 'TEST'). 'TEST' is the default
     */
    mode: string;

    /**
     * Name of the customer
     */
    cust_name?: string;

    /**
     * Email of the customer
     */
    cust_email: string;

    /**
     * ID of the customer
     */
    cust_id?: string;

    /**
     * Flag to indicate whether you want the customer's card to be tokenised, 
     * a tokenised value would be returned when you requery to confrim the transaction status
     */
    tokenise_card?: boolean;

    /**
     * Access token value gotten from passport
     */
    access_token?: boolean;

    /**
     * Called after a successful payment
     */
    onComplete?: (response?: any) => void;

}